CORSRule class

Specifies a cross-origin access rule for an Amazon S3 bucket.

Constructors

CORSRule(String? allowedHeaders, String? allowedMethods, String? allowedOrigins, String? exposeHeaders, int? maxAgeSeconds)
CORSRule.fromXml(XmlElement? xml)

Properties

allowedHeaders ↔ String?
Headers that are specified in the Access-Control-Request-Headers header. These headers are allowed in a preflight OPTIONS request. In response to any preflight OPTIONS request, Amazon S3 returns any requested headers that are allowed.
getter/setter pair
allowedMethods ↔ String?
An HTTP method that you allow the origin to execute. Valid values are GET, PUT, HEAD, POST, and DELETE.
getter/setter pair
allowedOrigins ↔ String?
One or more origins you want customers to be able to access the bucket from.
getter/setter pair
exposeHeaders ↔ String?
One or more headers in the response that you want customers to be able to access from their applications (for example, from a JavaScript XMLHttpRequest object).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxAgeSeconds ↔ int?
The time in seconds that your browser is to cache the preflight response for the specified resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml() → XmlNode

Operators

operator ==(Object other) → bool
The equality operator.
inherited