DeletedObject class

Information about the deleted object.

Constructors

DeletedObject(bool? deleteMarker, String? deleteMarkerVersionId, String? key, String? versionId)
DeletedObject.fromXml(XmlElement xml)

Properties

deleteMarker ↔ bool?
Specifies whether the versioned object that was permanently deleted was (true) or was not (false) a delete marker. In a simple DELETE, this header indicates whether (true) or not (false) a delete marker was created.
getter/setter pair
deleteMarkerVersionId ↔ String?
The version ID of the delete marker created as a result of the DELETE operation. If you delete a specific object version, the value returned by this header is the version ID of the object version deleted.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
The name of the deleted object.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionId ↔ String?
The version ID of the deleted object.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml() → XmlNode

Operators

operator ==(Object other) → bool
The equality operator.
inherited